@@ -153,12 +153,12 @@ CCalendarWidget::CCalendarWidget (QWidget *parent, const QString &a_dir_days): Q
   moon_phase_algo = MOON_PHASE_TRIG2;
   moon_mode = false;
   moon_tiles.load (":/images/moon-phases.png");
+  northern_hemisphere = true;
 }
 
 
 void CCalendarWidget::paintCell (QPainter *painter, const QRect &rect, const QDate &date) const
 {
-
   QSize fsize = fontMetrics().size (Qt::TextSingleLine, "A");
 
   if (moon_mode)
@@ -172,8 +172,8 @@ void CCalendarWidget::paintCell (QPainter *painter, const QRect &rect, const QDa
 
       //вычисляем ряд и колонку
 
-     //правильно
-     //int row = moon_day / 8;
+      //правильно
+      //int row = moon_day / 8;
 
       int cursorOffset = moon_day;
 
@@ -246,31 +246,31 @@ void CCalendarWidget::do_update()
 
 int moon_phase_by_algo (int v, int year, int month, int day)
 {
- int r = 0;
+  int r = 0;
 
- switch (v)
-        {
-         case MOON_PHASE_TRIG2:
-                               r = moon_phase_trig2 (year, month, day);
-                               break;
-
-         case MOON_PHASE_TRIG1:
-                               r = moon_phase_trig1 (year, month, day);
-                               break;
-
-         case MOON_PHASE_CONWAY:
-                               r = moon_phase_conway (year, month, day);
-                               break;
-
-         case MOON_PHASE_LEUESHKANOV:
-                                r = moon_phase_leueshkanov (year, month, day);
+  switch (v)
+         {
+          case MOON_PHASE_TRIG2:
+                                r = moon_phase_trig2 (year, month, day);
                                 break;
 
-         case MOON_PHASE_SIMPLE:
+          case MOON_PHASE_TRIG1:
+                                r = moon_phase_trig1 (year, month, day);
+                                break;
+
+          case MOON_PHASE_CONWAY:
+                                 r = moon_phase_conway (year, month, day);
+                                 break;
+
+          case MOON_PHASE_LEUESHKANOV:
+                                      r = moon_phase_leueshkanov (year, month, day);
+                                      break;
+
+          case MOON_PHASE_SIMPLE:
                                  r = moon_phase_simple (year, month, day);
                                  break;
 
-        };
+         };
 
- return r;
+  return r;
 }
