@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2014 by Peter Semiletov                                          *
+ *   2007-2015 by Peter Semiletov                                          *
  *   tea@list.ru                                                           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -221,19 +221,14 @@ CDocument::CDocument (QObject *parent): QObject (parent)
 
 //  qDebug() << "defined(Q_OS_WIN) || defined(Q_OS_OS2)";
 
-#elif defined(Q_OS_LINUX)
+#elif defined(Q_OS_UNIX)
 
   eol = "\n";
-
-  //qDebug() << "Q_OS_LINUX";
-
-
+/*
 #elif defined(Q_OS_MAC)
 
   eol = "\r";
-
-  //qDebug() << "Q_OS_MAC";
-
+*/
 #endif
 
   //qDebug() << "CDocument()";
@@ -259,8 +254,7 @@ CDocument::~CDocument()
      {
       if (QMessageBox::warning (0, "TEA",
                                 tr ("%1 has been modified.\n"
-                                "Do you want to save your changes?")
-                                .arg (file_name),
+                                "Do you want to save your changes?").arg (file_name),
                                 QMessageBox::Ok | QMessageBox::Default,
                                 QMessageBox::Cancel | QMessageBox::Escape) == QMessageBox::Ok)
          save_with_name (file_name, charset);
@@ -568,9 +562,8 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
 
   QString fname = holder->hls.value (ext);
   
-  qDebug() << "hl fname is " << fname;
+  //qDebug() << "hl fname is " << fname;
   
-
   if (fname.isNull() || fname.isEmpty())
      return;
 
@@ -589,7 +582,6 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
   
   highlighter = new CSyntaxHighlighterQRegExp (textEdit->document(), this, fname);
   
-  
 #endif  
   
   //highlighter->load_from_xml (fname);
@@ -1099,7 +1091,6 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
      qDebug() << "xml parse error";
 
   } //cycle
-  
 }
 
 
@@ -1364,13 +1355,176 @@ void document_holder::load_from_session (const QString &fileName)
 }
 
 
+QHash <QString, QString> document_holder::load_eclipse_theme_xml (const QString &fname)
+{
+  QHash <QString, QString> result;
+ 
+  QString temp = qstring_load (fname);
+  QXmlStreamReader xml (temp);
+
+   while (! xml.atEnd())
+        {
+         xml.readNext();
+
+         QString tag_name = xml.name().toString();
+         
+         if (xml.isStartElement())
+            {
+
+            if (tag_name == "colorTheme")
+             {
+                  
+                 log->log (xml.attributes().value ("id").toString());
+                 log->log (xml.attributes().value ("name").toString());
+                 log->log (xml.attributes().value ("modified").toString());
+                 log->log (xml.attributes().value ("author").toString());
+                 log->log (xml.attributes().value ("website").toString());
+                }
+
+         
+            if (tag_name == "singleLineComment")
+               {
+                QString t = xml.attributes().value ("color").toString();
+                if (! t.isNull() || ! t.isEmpty())
+                     result.insert ("single comment", t);
+               }
+         
+
+            if (tag_name == "class")
+               {
+                QString t = xml.attributes().value ("color").toString();
+                if (! t.isNull() || ! t.isEmpty())
+                   {
+                    result.insert ("class", t);
+                    result.insert ("type", t);
+                   }
+               }
+
+         
+         if (tag_name == "operator")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+                     result.insert ("operator", t);
+            }
+
+         
+         
+         if (tag_name == "string")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+                 result.insert ("quotes", t);
+            }
+
+         
+         
+         if (tag_name == "multiLineComment")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+                 result.insert ("mcomment-start", t);
+            }
+
+         
+         
+         if (tag_name == "foreground")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+                 {
+                  result.insert ("text", t);
+                  result.insert ("functions", t);
+                  result.insert ("modifiers", t);
+                  result.insert ("margin_color", t);
+                  result.insert ("digits", t);
+                  result.insert ("digits-float", t);
+                  result.insert ("label", t);
+                  result.insert ("include", t);
+                  result.insert ("preproc", t);
+                 }
+             }
+
+         if (tag_name == "background")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+                { 
+                 result.insert ("background", t);
+                 result.insert ("linenums_bg", t);
+                }
+            }
+         
+         
+         if (tag_name == "selectionForeground")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+                result.insert ("sel-text", t);
+            }
+
+         
+         
+         if (tag_name == "selectionBackground")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+               result.insert ("sel-background", t);
+            }
+
+         
+         if (tag_name == "keyword")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+                {
+                 result.insert ("keywords", t);
+                result.insert ("tags", t);
+                }
+             }
+
+        	 
+        	 
+       	 if (tag_name == "currentLine")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+                result.insert ("cur_line_color", t);
+            }
+
+        	 
+         if (tag_name == "bracket")
+            {
+             QString t = xml.attributes().value ("color").toString();
+             if (! t.isNull() || ! t.isEmpty())
+                 result.insert ("brackets", t);
+             }
+             
+        }//is start
+
+  if (xml.hasError())
+     qDebug() << "xml parse error";
+
+  } //cycle
+  
+
+   result.insert ("error", "red");
+   
+   return result; 
+}
+
+
 void document_holder::load_palette (const QString &fileName)
 {
   if (! file_exists (fileName))
       return;
 
   palette.clear();
-  palette = hash_load_keyval (fileName);
+  
+  if (file_get_ext (fileName) == "xml")
+     palette = load_eclipse_theme_xml (fileName);
+  else
+      palette = hash_load_keyval (fileName);
 }
 
 
@@ -1834,7 +1988,7 @@ void document_holder::open_current()
 {
   QAction *act = qobject_cast<QAction *>(sender());
 
-  QStringList current_files; 
+  //QStringList current_files; 
  
 /* foreach (CDocument *d, list)
          current_files.prepend (d->file_name);
@@ -1847,12 +2001,7 @@ void document_holder::open_current()
  
   CDocument *d = get_document_by_fname (act->text());
   if (d)
-     {
       tab_widget->setCurrentIndex (tab_widget->indexOf (d->tab_page));
- //     return d;
-     }
-
- 
  
  
 //  update_current_files_menu();
@@ -1872,9 +2021,8 @@ void document_holder::update_current_files_menu()
 {
  QStringList current_files; 
  
- foreach (CDocument *d, list)
+  foreach (CDocument *d, list)
          current_files.prepend (d->file_name);
-
  
   current_files_menu->clear();
   create_menu_from_list (this, current_files_menu, current_files, SLOT(open_current()));
@@ -1960,4 +2108,4 @@ void CSyntaxHighlighter::highlightBlock (const QString &text)
  
  
  * 
- */
\ No newline at end of file
+ */
