@@ -1,6 +1,6 @@
 /***************************************************************************
- *   2007-2014 by Peter Semiletov                                          *
- *   tea@list.ru                                                           *
+ *   2007-2014 by Peter Semiletov <tea@list.ru>                            *
+ *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -138,7 +138,7 @@ class CSyntaxHighlighter: public QSyntaxHighlighter
 {
 public:
  
-  CSyntaxHighlighter (QTextDocument *parent): QSyntaxHighlighter (parent) {};
+  CSyntaxHighlighter (QTextDocument *parent): QSyntaxHighlighter (parent) { document = 0; casecare = true; wrap = false;};
  
   CDocument *document;
   bool casecare;
@@ -155,7 +155,6 @@ public:
 };
 
 
-
 class CSyntaxHighlighterQRegExp: public CSyntaxHighlighter
 {
   Q_OBJECT
@@ -315,8 +314,6 @@ public:
   QStringList recent_files;
   QString recent_list_fname;
 
-  //QStringList current_files;
-
   
   ~document_holder();
 
@@ -329,6 +326,9 @@ public:
 
   Q_INVOKABLE void save_to_session (const QString &fileName);
   Q_INVOKABLE void load_from_session (const QString &fileName);
+  
+  QHash <QString, QString> load_eclipse_theme_xml (const QString &fname);
+
   void load_palette (const QString &fileName);
 
   void close_by_idx (int i);
@@ -339,7 +339,6 @@ public:
   void add_to_recent (CDocument *d);
   void update_recent_menu();
 
-  //void add_to_current_files (CDocument *d);
   void update_current_files_menu();
 
   Q_INVOKABLE CDocument* get_current();
