@@ -29,6 +29,10 @@
 #include <QDebug>
 #include <QApplication>
 #include <QDateTime>
+#include <QSettings>
+
+
+extern QSettings *settings;
 
 
 void CFMan::dir_up()
@@ -57,11 +61,58 @@ void CFMan::nav (const QString &path)
 
   setModel (0);
 
+  QDir::SortFlags sort_flags = 0;
+  
+  if (sort_order == Qt::DescendingOrder)
+     sort_flags |= QDir::Reversed;
+  
+  if (sort_mode == 0)
+     sort_flags |= QDir::Name;
+
+  if (sort_mode == 1)
+     sort_flags |= QDir::Size;
+  
+  if (sort_mode == 2)
+     sort_flags |= QDir::Time;
+
+  sort_flags |= QDir::DirsFirst;
+  sort_flags |= QDir::IgnoreCase;
+  sort_flags |= QDir::LocaleAware;
+
+  
+  
   mymodel->removeRows (0, mymodel->rowCount());
+  
   QFileInfoList lst = dir.entryInfoList (QDir::Dirs | QDir::Hidden | QDir::NoDotAndDotDot |
-                                         QDir::Files | QDir::Drives, QDir::Name |
+                                         QDir::Files | QDir::Drives, 
+                                         sort_flags);
+
+  
+  
+  
+  
+  /*QFileInfoList lst = dir.entryInfoList (QDir::Dirs | QDir::Hidden | QDir::NoDotAndDotDot |
+                                         QDir::Files | QDir::Drives, 
+                                         QDir::Name |
                                          QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware);
 
+  */
+  /*
+    QDir::Name   0x00  Sort by name.
+QDir::Time  0x01  Sort by time (modification time).
+QDir::Size  0x02  Sort by file size.
+QDir::Type  0x80  Sort by file type (extension).
+QDir::Unsorted 0x03  Do not sort.
+QDir::NoSort   -1 Not sorted by default.
+QDir::DirsFirst   0x04  Put the directories first, then the files.
+QDir::DirsLast 0x20  Put the files first, then the directories.
+QDir::Reversed 0x08  Reverse the sort order.
+QDir::IgnoreCase  0x10  Sort case-insensitively.
+QDir::LocaleAware 0x40  Sort items appropriately using the current locale settings.
+    
+    
+   */
+  
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 
   if (path != "/")
@@ -179,14 +230,42 @@ void CFMan::append_dot_entry (const QString &fname)
 }
 
 
+void CFMan::header_view_sortIndicatorChanged (int logicalIndex, Qt::SortOrder order)
+{
+//  qDebug() << "header col = " << logicalIndex << " order = " << order; 
+  sort_order = order;
+  sort_mode = logicalIndex;
+  
+  
+  settings->setValue ("fman_sort_mode", sort_mode);
+  settings->setValue ("fman_sort_order", sort_order);
+
+  
+  refresh();  
+}
+
+
 CFMan::CFMan (QWidget *parent): QTreeView (parent)
 {
+//  sort_mode = 0;
+//  sort_order = Qt::AscendingOrder;
+ 
+  sort_mode = settings->value ("fman_sort_mode", 0).toInt(); 
+  sort_order = Qt::SortOrder (settings->value ("fman_sort_order", 0).toInt()); 
+  
+   
   mymodel = new QStandardItemModel (0, 3, parent);
 
   mymodel->setHeaderData (0, Qt::Horizontal, QObject::tr ("Name"));
   mymodel->setHeaderData (1, Qt::Horizontal, QObject::tr ("Size"));
   mymodel->setHeaderData (2, Qt::Horizontal, QObject::tr ("Modified at"));
 
+  /*
+   
+   QStandardItem *col = mymodel (0);
+    
+   */
+  
   setRootIsDecorated (false);
 
   setAlternatingRowColors (true);
@@ -200,14 +279,21 @@ CFMan::CFMan (QWidget *parent): QTreeView (parent)
 #if QT_VERSION >= 0x050000
 
   header()->setSectionResizeMode (QHeaderView::ResizeToContents);
-
+  header()->setSectionsClickable (true);
+ 
+  
 #else
 
   header()->setResizeMode (QHeaderView::ResizeToContents);
-
+  header()->setClickable (true);
+  
 #endif
 
+  header()->setSortIndicator (sort_mode, sort_order);
+  header()->setSortIndicatorShown (true);  
 
+  connect (header(), SIGNAL(sortIndicatorChanged(int, Qt::SortOrder)), this, SLOT(header_view_sortIndicatorChanged(int, Qt::SortOrder)));
+  
   header()->setStretchLastSection (false);
 
   setSelectionMode (QAbstractItemView::ExtendedSelection);
@@ -479,3 +565,11 @@ void CFMan::drawRow (QPainter *painter, const QStyleOptionViewItem &option, cons
     QTreeView::drawRow (painter, option, index);
 }
 
+/*
+CFMan::~CFMan()
+{
+  settings->setValue ("fman_sort_mode", sort_mode);
+  settings->setValue ("fman_sort_order", sort_order);
+  qDebug() << "CFMan::~CFMan()";
+}
+*/
