@@ -28,10 +28,15 @@
 CLogMemo::CLogMemo (QPlainTextEdit *m)
 {
   memo = m;
+  
   setObjectName ("logmemo");
   memo->setFocusPolicy (Qt::ClickFocus);
   memo->setUndoRedoEnabled (false);
   memo->setReadOnly (true);
+  
+  memo->setTextInteractionFlags (Qt::LinksAccessibleByMouse | Qt::TextSelectableByMouse | 
+				 Qt::TextSelectableByKeyboard);
+  
 }
 
 
