@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2007-2014 by Peter Semiletov                            *
- *   tea@list.ru                                           *
+ *   Copyleft 2007-2014 by Peter Semiletov <tea@list.ru>                   *
+ *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,9 +24,7 @@
 
 #include "rvln.h"
 
-#ifndef Q_OS_OS2
 #include "single_application.h"
-#endif
 
 int main (int argc, char *argv[])
 {
