@@ -510,6 +510,12 @@ main window callbacks
   void fn_sort_casecare();
   void fn_sort_casecareless();
 
+  void fn_sort_latex_table_by_col_abc();
+  void fn_table_swap_cells();
+  void fn_table_delete_cells();
+  void fn_table_copy_cells();
+      
+  
   void fn_flip_a_list();
   void fn_insert_loremipsum();
   void fn_insert_template_html();
@@ -567,7 +573,6 @@ main window callbacks
 
   void fn_spell_suggest();
 
-
   void cmb_spellchecker_currentIndexChanged (const QString &text);
 
 #ifdef HUNSPELL_ENABLE
