@@ -1293,10 +1293,6 @@ opera=opera %s</source>
         <source>Set Windows end of line</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Set traditional Mac end of line</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>End of line: </source>
         <translation type="unfinished"></translation>
@@ -1528,10 +1524,6 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>HTML5 template</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&lt;b&gt;TEA %1 @ http://semiletov.org/tea&lt;/b&gt;&lt;br&gt;by Peter Semiletov (e-mail: tea@list.ru, site: semiletov.org)&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>snippet %1 is not exists</source>
         <translation type="unfinished"></translation>
@@ -1657,5 +1649,33 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Charset for file open from command line</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Set old Mac end of line (CR)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cells</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sort table by column ABC</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Swap cells</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete by column</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy by column[s]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov - tea@list.ru&lt;br&gt;site 1: http://semiletov.org/tea&lt;br&gt;site 2: http://tea.ourproject.org&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
